<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ml">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>ആഡ്-ഓണുകൾ</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="15"/>
        <source>Advanced Settings</source>
        <translation>വിപുലമായ ക്രമീകരണങ്ങൾ</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>&quot;വിപുലമായ ക്രമീകരണങ്ങൾ&quot; സിസ്റ്റം ക്രമീകരണങ്ങൾ ഉപയോഗിക്കുന്ന ഇൻപുട്ട് മെത്തോഡിന് മാത്രമേ ബാധകമാകൂ. ഇൻപുട്ട് മെത്തോഡിന് സ്വന്തം ക്രമീകരണങ്ങൾ ഉണ്ടെങ്കിൽ, അത് സ്വന്തം ക്രമീകരണങ്ങൾ പ്രയോഗിക്കും.</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="54"/>
        <source>Global Config</source>
        <translation>ആഗോള കോൺഫിഗറേഷൻ</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="70"/>
        <source>Add-ons</source>
        <translation>ആഡ്-ഓണുകൾ</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="81"/>
        <source>Keyboard layout</source>
        <translation>കീബോർഡ് ലേഔട്ട്</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="151"/>
        <source>Please enter a new shortcut</source>
        <translation>ദയവായി ഒരു പുതിയ കുറുക്കുവഴി നൽകുക</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="152"/>
        <source>Move Up</source>
        <translation>മുകളിലേക്ക് നീക്കുക</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="160"/>
        <source>Move Down</source>
        <translation>താഴേക്ക് നീക്കുക</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="168"/>
        <source>Settings</source>
        <translation>ക്രമീകരണങ്ങൾ</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="176"/>
        <source>Remove</source>
        <translation>നീക്കം ചെയ്യുക</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="35"/>
        <source>Add input method</source>
        <translation>ഇൻപുട്ട് മെത്തോഡ് ചേർക്കുക</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="41"/>
        <source>Search</source>
        <translation>തിരയുക</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="109"/>
        <source>Find more in App Store</source>
        <translation>ആപ്പ് സ്റ്റോറിൽ കൂടുതൽ കണ്ടെത്തുക</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="129"/>
        <source>Cancel</source>
        <translation>റദ്ദാക്കുക</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="136"/>
        <source>Add</source>
        <translation>ചേർക്കുക</translation>
    </message>
</context>
<context>
    <name>KeyboardLayout</name>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="16"/>
        <source>Keyboard layout</source>
        <translation>കീബോർഡ് ലേഔട്ട്</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="34"/>
        <source>done</source>
        <translation>പൂർത്തിയായി</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="34"/>
        <source>edit</source>
        <translation>എഡിറ്റ് ചെയ്യുക</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="57"/>
        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
        <translation>കീബോർഡ് ലേഔട്ട് ചേർക്കുമ്പോഴോ മാറുമ്പോഴോ പ്രവർത്തിക്കുന്നത് ഉറപ്പാക്കാൻ &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;ഇൻപുട്ട് മെത്തോഡ് മാനേജ്മെന്റിൽ&lt;/a&gt; അനുബന്ധ ഇൻപുട്ട് മെത്തോഡ് ചേർക്കുക.</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="142"/>
        <source>Add new keyboard layout...</source>
        <translation>പുതിയ കീബോർഡ് ലേഔട്ട് ചേർക്കുക...</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutModule</name>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="16"/>
        <source>Keyboard layout</source>
        <translation>കീബോർഡ് ലേഔട്ട്</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
        <source>done</source>
        <translation>പൂർത്തിയായി</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
        <source>edit</source>
        <translation>എഡിറ്റ് ചെയ്യുക</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="57"/>
        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
        <translation>കീബോർഡ് ലേഔട്ട് ചേർക്കുമ്പോഴോ മാറുമ്പോഴോ പ്രവർത്തിക്കുന്നത് ഉറപ്പാക്കാൻ &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;ഇൻപുട്ട് മെത്തോഡ് മാനേജ്മെന്റിൽ&lt;/a&gt; അനുബന്ധ ഇൻപുട്ട് മെത്തോഡ് ചേർക്കുക.</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="140"/>
        <source>Add new keyboard layout...</source>
        <translation>പുതിയ കീബോർഡ് ലേഔട്ട് ചേർക്കുക...</translation>
    </message>
</context>
<context>
    <name>LayoutsChooser</name>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="30"/>
        <source>Add new keyboard layout</source>
        <translation>പുതിയ കീബോർഡ് ലേഔട്ട് ചേർക്കുക</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="38"/>
        <source>Search</source>
        <translation>തിരയുക</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="67"/>
        <source>Current language keyboard layouts</source>
        <translation>നിലവിലെ ഭാഷയുടെ കീബോർഡ് ലേഔട്ടുകൾ</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="90"/>
        <source>Cancel</source>
            <translation>റദ്ദാക്കുക</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="97"/>
        <source>Add</source>
        <translation>ചേർക്കുക</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>ഇൻപുട്ട് മെത്തോഡ് മാനേജ്മെന്റ്</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="33"/>
        <source>Add input method</source>
        <translation>ഇൻപുട്ട് മെത്തോഡ് ചേർക്കുക</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="12"/>
        <location filename="../qml/ShortcutsModule.qml" line="14"/>
        <location filename="../qml/ShortcutsModule.qml" line="151"/>
        <location filename="../qml/ShortcutsModule.qml" line="152"/>
        <source>None</source>
        <translation>ഒന്നുമില്ല</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="119"/>
        <source>Shortcuts</source>
        <translation>കുറുക്കുവഴികൾ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="134"/>
        <source>Restore Defaults</source>
        <translation>സ്ഥിരമായ ക്രമീകരണങ്ങൾ പുനഃസ്ഥാപിക്കുക</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="200"/>
        <source>Scroll between input methods</source>
        <translation>ഇൻപുട്ട് മെത്തോഡുകൾ തമ്മിൽ സ്ക്രോൾ ചെയ്യുക</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="230"/>
        <source>Turn on or off input methods</source>
        <translation>ഇൻപുട്ട് മെത്തോഡുകൾ ഓൺ അല്ലെങ്കിൽ ഓഫ് ചെയ്യുക</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="273"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>ഇത് നിലവിൽ ഉപയോഗിക്കുന്ന ഇൻപുട്ട് മെത്തോഡ് ഓൺ അല്ലെങ്കിൽ ഓഫ് ചെയ്യുന്നു. ഇൻപുട്ട് മെത്തോഡ് ഉപയോഗിക്കുന്നില്ലെങ്കിൽ അല്ലെങ്കിൽ ആദ്യത്തെ ഇൻപുട്ട് മെത്തോഡ് കീബോർഡ് അല്ലെങ്കിൽ, ആദ്യത്തെ ഇൻപുട്ട് മെത്തോഡും നിലവിൽ ഉപയോഗിക്കുന്ന കീബോർഡ്/ഇൻപുട്ട് മെത്തോഡും തമ്മിൽ മാറുന്നു.</translation>
    </message>
</context>
<context>
    <name>dcc::Locale::dialectNames</name>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="62"/>
        <source>Traditional Chinese (Chinese Hong Kong)</source>
        <translation>പരമ്പരാഗത ചൈനീസ് (ഹോങ്കോങ് ചൈനീസ്)</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="65"/>
        <source>Traditional Chinese (Chinese Taiwan)</source>
        <translation>പരമ്പരാഗത ചൈനീസ് (തായ്‌വാൻ ചൈനീസ്)</translation>
    </message>
</context>
<context>
    <name>dcc::Locale::regionNames</name>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="86"/>
        <source>Taiwan China</source>
        <translation>തായ്‌വാൻ ചൈന</translation>
    </message>
</context>
<context>
    <name>dccV25::KeyboardController</name>
    <message>
        <location filename="../keyboard-layout/operation/keyboardcontroller.cpp" line="55"/>
        <source>This shortcut conflicts with [%1]</source>
            <translation>ഈ കുറുക്കുവഴി [%1] ൽ പൊരുത്തക്കേടുണ്ട്</translation>
    </message>
</context>
<context>
    <name>dccV25::ShortcutModel</name>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="248"/>
        <source>System</source>
        <translation>സിസ്റ്റം</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="253"/>
        <source>Window</source>
        <translation>വിൻഡോ</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="258"/>
        <source>Workspace</source>
        <translation>വർക്ക്സ്പേസ്</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="263"/>
        <source>AssistiveTools</source>
        <translation>സഹായ ഉപകരണങ്ങൾ</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="268"/>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="339"/>
        <source>Custom</source>
        <translation>ഇഷ്ടാനുസൃതം</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="394"/>
        <source>None</source>
        <translation>ഒന്നുമില്ല</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>ഇൻപുട്ട് മെത്തോഡുകൾ</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>ഇൻപുട്ട് മെത്തോഡ് മാനേജ്മെന്റ്, ഇൻപുട്ട് മെത്തോഡ് കുറുക്കുവഴികൾ, വിപുലമായ ക്രമീകരണങ്ങൾ</translation>
    </message>
</context>
</TS>